@@ -20,11 +20,11 @@ def give_me_a_timestamp_from_this_string(str_date: str):
 
 
 def the_time_in_iso_now_is():
-    return pendulum.now().in_timezone('UTC').to_iso8601_string()
+    return pendulum.now().to_iso8601_string()
 
 
 def the_time_now_is() -> float:
-    return pendulum.now().in_timezone('UTC').timestamp()
+    return pendulum.now().timestamp()
 
 
 def go_back_in_time(time_to_reduce: float, seconds_to_reduce: int):
@@ -46,12 +46,12 @@ def is_time_between(begin_time: float, end_time: float, check_time: float = None
 
 def is_this_time_behind(base_time: float):
     # If check time is not given, default to current UTC time
-    return pendulum.from_timestamp(base_time) < pendulum.now().in_timezone('UTC')
+    return pendulum.from_timestamp(base_time) < pendulum.now()
 
 
 def is_this_time_ahead(base_time: float):
     # If check time is not given, default to current UTC time
-    return pendulum.from_timestamp(base_time) > pendulum.now().in_timezone('UTC')
+    return pendulum.from_timestamp(base_time) > pendulum.now()
 
 
 def countdown(base_date: float):
